summaryrefslogtreecommitdiffstats
path: root/chrome/browser/process_singleton_linux.cc
diff options
context:
space:
mode:
Diffstat (limited to 'chrome/browser/process_singleton_linux.cc')
-rw-r--r--chrome/browser/process_singleton_linux.cc4
1 files changed, 2 insertions, 2 deletions
diff --git a/chrome/browser/process_singleton_linux.cc b/chrome/browser/process_singleton_linux.cc
index da80b2b..36cced1 100644
--- a/chrome/browser/process_singleton_linux.cc
+++ b/chrome/browser/process_singleton_linux.cc
@@ -601,7 +601,7 @@ void ProcessSingleton::LinuxWatcher::OnFileCanReadWithoutBlocking(int fd) {
}
void ProcessSingleton::LinuxWatcher::StartListening(int socket) {
- DCHECK(ChromeThread::CurrentlyOn(ChromeThread::IO));
+ DCHECK(BrowserThread::CurrentlyOn(BrowserThread::IO));
// Watch for client connections on this socket.
MessageLoopForIO* ml = MessageLoopForIO::current();
ml->AddDestructionObserver(this);
@@ -978,7 +978,7 @@ bool ProcessSingleton::Create() {
if (listen(sock, 5) < 0)
NOTREACHED() << "listen failed: " << safe_strerror(errno);
// Normally we would use ChromeThread, but the IO thread hasn't started yet.
// Using g_browser_process, we start the thread so we can listen on the
// socket.
MessageLoop* ml = g_browser_process->io_thread()->message_loop();
@@ -978,7 +978,7 @@ bool ProcessSingleton::Create() {
if (listen(sock, 5) < 0)
NOTREACHED() << "listen failed: " << safe_strerror(errno);
- // Normally we would use ChromeThread, but the IO thread hasn't started yet.
+ // Normally we would use BrowserThread, but the IO thread hasn't started yet.
// Using g_browser_process, we start the thread so we can listen on the
// socket.